@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2006 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // A 'ServerMediaSubsession' object that represents an existing
 // 'RTPSink', rather than one that creates new 'RTPSink's on demand.
 // Implementation
@@ -133,7 +133,7 @@ void PassiveServerMediaSubsession::startStream(unsigned /*clientSessionId*/,
   // many times on the same "RTCPInstance", and (ii) the "RTCPInstance" remains
   // in existence after "deleteStream()" is called.
   rtpSeqNum = fRTPSink.currentSeqNo();
-  rtpTimestamp = fRTPSink.currentTimestamp();
+  rtpTimestamp = fRTPSink.presetNextTimestamp();
 }
 
 PassiveServerMediaSubsession::~PassiveServerMediaSubsession() {
