@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
 // A generic RTSP client
 // Implementation
 
@@ -146,10 +146,15 @@ void RTSPClient::reset() {
 static char* getLine(char* startOfLine) {
   // returns the start of the next line, or NULL if none
   for (char* ptr = startOfLine; *ptr != '\0'; ++ptr) {
+    // Check for the end of line: \r\n (but also accept \r or \n by itself):
     if (*ptr == '\r' || *ptr == '\n') {
       // We found the end of the line
-      *ptr++ = '\0';
-      if (*ptr == '\n') ++ptr;
+      if (*ptr == '\r') {
+	*ptr++ = '\0';
+	if (*ptr == '\n') ++ptr;
+      } else {
+        *ptr++ = '\0';
+      }
       return ptr;
     }
   }
@@ -281,6 +286,7 @@ char* RTSPClient::describeURL(char const* url, Authenticator* authenticator,
 	  char* result = describeURL(redirectionURL, authenticator, allowKasennaProtocol);
 	  delete[] redirectionURL;
 	  delete[] serverType;
+	  delete[] cmd;
 	  return result;
 	}
       }
@@ -502,9 +508,9 @@ char* RTSPClient::sendOptionsCmd(char const* url,
       // (and no username,password pair was supplied separately):
       if (username == NULL && password == NULL
 	  && parseRTSPURLUsernamePassword(url, username, password)) {
-	Authenticator authenticator;
-	authenticator.setUsernameAndPassword(username, password);
-	result = sendOptionsCmd(url, username, password, &authenticator);
+	Authenticator newAuthenticator;
+	newAuthenticator.setUsernameAndPassword(username, password);
+	result = sendOptionsCmd(url, username, password, &newAuthenticator);
 	delete[] username; delete[] password; // they were dynamically allocated
 	break;
       } else if (username != NULL && password != NULL) {
@@ -757,7 +763,7 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
       sessionStr = new char[20+strlen(fLastSessionId)];
       sprintf(sessionStr, "Session: %s\r\n", fLastSessionId);
     } else {
-      sessionStr = "";
+      sessionStr = strDup("");
     }
 
     char* transportStr = NULL;
@@ -872,6 +878,7 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
 	rtpNumber = subsession.clientPortNum();
 	if (rtpNumber == 0) {
 	  envir().setResultMsg("Client port number unknown\n");
+	  delete[] authenticatorStr; delete[] sessionStr; delete[] setupStr;
 	  break;
 	}
 	rtcpNumber = rtpNumber + 1;
@@ -909,9 +916,7 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
 	    sessionStr,
 	    authenticatorStr,
 	    fUserAgentHeaderStr);
-    delete[] authenticatorStr;
-    if (sessionStr[0] != '\0') delete[] sessionStr;
-    delete[] setupStr; delete[] transportStr;
+    delete[] authenticatorStr; delete[] sessionStr; delete[] setupStr; delete[] transportStr;
 
     // And then send it:
     if (!sendRequest(cmd, "SETUP")) break;
@@ -926,6 +931,7 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
     // For now, ignore other headers.
     char* lineStart;
     char* sessionId = new char[fResponseBufferSize]; // ensures we have enough space
+    unsigned cLength = 0;
     while (1) {
       lineStart = nextLineStart;
       if (lineStart == NULL) break;
@@ -959,6 +965,10 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
 	subsession.rtcpChannelId = rtcpChannelId;
 	continue;
       }
+
+      // Also check for a "Content-Length:" header.  Some weird servers include this
+      // in the RTSP "SETUP" response.
+      if (sscanf(lineStart, "Content-Length: %d", &cLength) == 1) continue;
     } 
     delete[] sessionId;
 
@@ -967,6 +977,14 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
       break;
     }
 
+    // If we saw a "Content-Length:" header in the response, then discard whatever
+    // included data it refers to:
+    if (cLength > 0) {
+      char* dummyBuf = new char[cLength];
+      getResponse1(dummyBuf, cLength);
+      delete[] dummyBuf;
+    }
+
     if (streamUsingTCP) {
       // Tell the subsession to receive RTP (and send/receive RTCP)
       // over the RTSP stream:
@@ -979,8 +997,10 @@ Boolean RTSPClient::setupMediaSubsession(MediaSubsession& subsession,
     } else {
       // Normal case.
       // Set the RTP and RTCP sockets' destination address and port
-      // from the information in the SETUP response: 
-      subsession.setDestinations(subsession.connectionEndpointAddress());
+      // from the information in the SETUP response (if present): 
+      netAddressBits destAddress = subsession.connectionEndpointAddress();
+      if (destAddress == 0) destAddress = fServerAddress;
+      subsession.setDestinations(destAddress);
     }
 
     delete[] cmd;
@@ -1426,16 +1446,18 @@ Boolean RTSPClient::setMediaSessionParameter(MediaSession& /*session*/,
       "Session: %s\r\n"
       "%s"
       "%s"
-      "%s: %s\r\n"
-      "\r\n";
+      "Content-length: %d\r\n\r\n"
+      "%s: %s\r\n";
 
+    unsigned parameterNameLen = strlen(parameterName); 
+    unsigned parameterValueLen = strlen(parameterValue); 
     unsigned cmdSize = strlen(cmdFmt)
       + strlen(fBaseURL)
       + 20 /* max int len */
       + strlen(fLastSessionId)
       + strlen(authenticatorStr)
       + fUserAgentHeaderStrSize
-      + strlen(parameterName) + strlen(parameterValue);
+      + parameterNameLen + parameterValueLen;
     cmd = new char[cmdSize];
     sprintf(cmd, cmdFmt,
 	    fBaseURL,
@@ -1443,6 +1465,7 @@ Boolean RTSPClient::setMediaSessionParameter(MediaSession& /*session*/,
 	    fLastSessionId,
 	    authenticatorStr,
 	    fUserAgentHeaderStr,
+	    parameterNameLen + parameterValueLen + 2, // the "+ 2" is for the \r\n after the parameter "name: value"
 	    parameterName, parameterValue);
     delete[] authenticatorStr;
 
@@ -1489,16 +1512,16 @@ Boolean RTSPClient::getMediaSessionParameter(MediaSession& /*session*/,
 	"%s"
 	"Content-type: text/parameters\r\n"
 	"Content-length: %d\r\n\r\n"
-	"%s\r\n"
-	"\r\n";
+	"%s\r\n";
       
+      unsigned parameterNameLen = strlen(parameterName); 
       unsigned cmdSize = strlen(cmdFmt)
 	+ strlen(fBaseURL)
 	+ 20 /* max int len */
 	+ strlen(fLastSessionId)
 	+ strlen(authenticatorStr)
 	+ fUserAgentHeaderStrSize
-	+ strlen(parameterName);
+	+ parameterNameLen;
       cmd = new char[cmdSize];
       sprintf(cmd, cmdFmt,
 	      fBaseURL,
@@ -1506,7 +1529,7 @@ Boolean RTSPClient::getMediaSessionParameter(MediaSession& /*session*/,
 	      fLastSessionId,
 	      authenticatorStr,
 	      fUserAgentHeaderStr,
-	      strlen(parameterName)+2,
+	      parameterNameLen + 2, // the "+ 2" is for the \r\n after the parameter name
 	      parameterName);
     } else {
       char* const cmdFmt =
@@ -2139,13 +2162,14 @@ unsigned RTSPClient::getResponse1(char*& responseBuffer,
     }
     bytesRead += bytesReadNow;
     
-    // Check whether we have "\r\n\r\n":
+    // Check whether we have "\r\n\r\n" (or "\r\r" or "\n\n"):
     char* lastToCheck = responseBuffer+bytesRead-4;
     if (lastToCheck < responseBuffer) continue;
     for (; p <= lastToCheck; ++p) {
       if (haveSeenNonCRLF) {
-	if (*p == '\r' && *(p+1) == '\n' &&
-	    *(p+2) == '\r' && *(p+3) == '\n') {
+	if ((*p == '\r' && *(p+1) == '\n' && *(p+2) == '\r' && *(p+3) == '\n')
+	    || (*(p+2) == '\r' && *(p+3) == '\r')
+	    || (*(p+2) == '\n' && *(p+3) == '\n')) {
 	  responseBuffer[bytesRead] = '\0';
 
 	  // Before returning, trim any \r or \n from the start:
